@@ -1,13 +1,10 @@
 package Mojolicious::Plugin::AutoRoutePm;
-$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.19';
+$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.20';
 use Mojo::Base 'Mojolicious::Plugin';
-# ABSTRACT: Mojolicious plugin to create routes by *.pm modules which are a controller
 
 use File::Find::Rule;
 use Module::Load;
 
-
-
 sub register {
   my ($self, $app, $conf) = @_;
 
@@ -67,15 +64,13 @@ sub register {
 		$template =~ s/^$routep//;
         # support for /url_component/index
         my $tr = $route->any($template)->to(app => $ctl, action => 'route');
-        $tr->any('/');
+        $tr->any('');
         # and for /url_component/index/a/b/x
         $tr->any('/*query');
         if ($template =~ s/$dindex$//) {
             # support for /url_component
             my $tr = $route->any($template)->to(app => $ctl, action => 'route');
             $tr->any('/');
-            # and for /url_component/a/b/x
-            $tr->any('/*query');
         }
 	}
   }
@@ -114,12 +109,8 @@ sub path_to_controller {
     return $url;
 }
 
-
-
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
@@ -127,10 +118,17 @@ __END__
 Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm modules which are a controller
 
 =for html <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/EmilianoBruni/mojolicious-plugin-autoroutepm?style=plastic"> <a href="https://travis-ci.com/EmilianoBruni/mojolicious-plugin-mongodbv2"><img alt="Travis tests" src="https://img.shields.io/travis/com/EmilianoBruni/mojolicious-plugin-autoroutepm?label=Travis%20tests&style=plastic"></a>
+<p>
+    <a href="https://github.com/emilianobruni/mojolicious-plugin-autoroutepm/actions/workflows/test.yml">
+        <img alt="github workflow tests" src="https://github.com/emilianobruni/mojolicious-plugin-autoroutepm/workflows/test.yml/badge.svg">
+    </a>
+    <img alt="Top language: " src="https://img.shields.io/github/languages/top/emilianobruni/mojolicious-plugin-autoroutepm">
+    <img alt="github last commit" src="https://img.shields.io/github/last-commit/emilianobruni/mojolicious-plugin-autoroutepm">
+</p>
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -145,6 +143,8 @@ version 0.19
 This module recursive passes through template_base_dir to find perl modules
 (*.pm) that are a subclass of Mojolicious::Controller and adds routes for them.
 
+=encoding UTF-8
+
 =head1 USAGE
 
 For module X::Y::Z it adds the decamelize version
@@ -175,6 +175,18 @@ a base_url like this
 
 Register plugin in L<Mojolicious> application.
 
+=head1 BUGS/CONTRIBUTING
+
+Please report any bugs through the web interface at L<https://github.com/EmilianoBruni/mojo-websocket-pubsub/issues>
+If you want to contribute changes or otherwise involve yourself in development, feel free to fork the Git repository from
+L<https://github.com/EmilianoBruni/mojo-websocket-pubsub/>.
+
+=head1 SUPPORT
+
+You can find this documentation with the perldoc command too.
+
+    perldoc Mojo::WebSocket::PubSub
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
@@ -191,3 +203,10 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT: Mojolicious plugin to create routes by *.pm modules which are a controller
+
+
+
